==> jbossas-plugin-1.3.1-sources.jar: com/xebialabs/deployit/plugin/jbossas/step/JbossasWaitForDeploymentsToCompleteStep.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.jbossas.step;

import com.xebialabs.deployit.Step;
import com.xebialabs.deployit.StepExecutionContext;
import com.xebialabs.deployit.plugin.jbossas.ci.JbossasServer;

@SuppressWarnings("serial")
public class JbossasWaitForDeploymentsToCompleteStep implements Step {

	public String getDescription() {
		return "Wait " + JbossasServer.DEPLOYMENT_COMPLETION_WAIT_TIME_MILLIS + "ms for JBoss server to complete deployments";
	}

	public boolean execute(StepExecutionContext ctx) {
		ctx.logOutput("Waiting " + JbossasServer.DEPLOYMENT_COMPLETION_WAIT_TIME_MILLIS + "ms for JBoss server to complete deployments");
		try {
			Thread.sleep(JbossasServer.DEPLOYMENT_COMPLETION_WAIT_TIME_MILLIS);
		} catch (InterruptedException ignored) {
		}
		return true;
	}

}

==> jbossas-plugin-1.4-sources.jar: com/xebialabs/deployit/plugin/jbossas/step/JbossasWaitForDeploymentsToCompleteStep.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.jbossas.step;

import com.xebialabs.deployit.Step;
import com.xebialabs.deployit.StepExecutionContext;

@SuppressWarnings("serial")
public class JbossasWaitForDeploymentsToCompleteStep implements Step {

	private int deploymentCompletionWaitTime = 0;

	public JbossasWaitForDeploymentsToCompleteStep(int deploymentCompletionWaitTime) {
		this.deploymentCompletionWaitTime = deploymentCompletionWaitTime;
	}

	public String getDescription() {
		return "Wait " + deploymentCompletionWaitTime + "ms for JBoss server to complete deployments";
	}

	public boolean execute(StepExecutionContext ctx) {
		ctx.logOutput("Waiting " + deploymentCompletionWaitTime + "ms for JBoss server to complete deployments");
		try {
			Thread.sleep(deploymentCompletionWaitTime);
		} catch (InterruptedException ignored) {
			Thread.currentThread().interrupt();
		}
		return true;
	}

}
